import type {LabeledValue, UserListResponseModel} from '@/helpers/models';
import {labeledGroup, userListResponseModel} from '@/helpers/mocks';

export const fetchMockData = <T>(mockData: T, name: string): Promise<T> => {
  console.debug(`${name}. VITE_USE_REAL_BACKEND===false in DEV mode. Returning mock data:`, mockData);
  return new Promise(resolve => {
    setTimeout(() => {
      resolve(mockData);
    }, 1000);
  });
};

export const getLabeledGroups = (): LabeledValue<string>[] => {
  const alphabet = 'abcdefghijklmnopqrstuvwxyz';
  return [...Array(5).keys()].map(i => ({
    label: labeledGroup.label.replace('a', alphabet.charAt(i)),
    value: labeledGroup.value.replace('a', alphabet.charAt(i)),
  }));
};

export const getUserListResponseModels = (): UserListResponseModel[] => {
  const users: UserListResponseModel[] = [userListResponseModel];

  for (let x = 2; x < 500; x++) {
    const y = JSON.parse(JSON.stringify(userListResponseModel));
    y.id = `user${x}`;
    y.attributes.account_activation_date.value = new Date(new Date(1900, 0, 1).getTime() + Math.random() * (new Date().getTime() - new Date(1900, 0, 1).getTime())).toDateString(); // eslint-disable-line no-mixed-operators
    y.attributes.schools.value = [...y.attributes.schools.value].sort(() => 0.5 - Math.random());
    y.attributes.username.value = y.id;
    if (x % 2 === 0) {
      y.allowedActions = ['edit'];
    }
    users.push(y);
  }
  return users;
};
